@@ -7,11 +7,12 @@ def read_file(file_path):
         content = file.read()
         return uploaded_filename, content
 
-def create_model(file_path, endpoint, client_token, data):
+def create_model(file_path, endpoint, token, data):
     uploaded_filename, content = read_file(file_path)
     url = f"{base_url}/training/{endpoint}"
     files = {'file': (uploaded_filename, content)}
-    headers = {"Authorization": client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     # Send the POST request
     response = requests.post(url, data=data, files=files, headers=headers)
     return response.json()
@@ -31,7 +32,7 @@ def comprehensive_modeling(file_path, client_token, data):
 
 
 
-def model_deployment(project_id,model_id,client_token):
+def model_deployment(project_id,model_id,token):
     try:
 
         data = {
@@ -40,7 +41,8 @@ def model_deployment(project_id,model_id,client_token):
         }
 
         url = f"{base_url}/training/deployment"
-        headers = {"Authorization":client_token}
+        access_token = 'Bearer '+ {token}
+        headers = {"Authorization": access_token}
         # Send the POST request
         response = requests.post(url, data=data, headers=headers)
         return response.json()
@@ -51,16 +53,17 @@ def model_deployment(project_id,model_id,client_token):
 
 
 
-def get_training_result(project_id,client_token):
+def get_training_result(project_id,token):
     url = f"{base_url}/training/get-results/{project_id}"
-    headers = {"Authorization": client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.get(url, headers=headers)
     response_json=response.json()
     return response_json
 
 
 
-def get_holdout_result(project_id,model_id,client_token):
+def get_holdout_result(project_id,model_id,token):
 
     data = {
         "project_id":project_id,
@@ -68,21 +71,24 @@ def get_holdout_result(project_id,model_id,client_token):
     }
 
     url = f"{base_url}/training/model-results"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.post(url,headers=headers,data=data)
     return response.json()
 
 
-def get_projectdetails(app_id,client_token):
+def get_projectdetails(app_id,token):
     url = f"{base_url}/training/project-details/{app_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
 
 
-def get_jobdetails(app_id,client_token):
+def get_jobdetails(app_id,token):
     url = f"{base_url}/training/job-details?app_id={app_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
  
@@ -92,48 +98,55 @@ def json_check(response):
     else:
         return f"Request failed with status code: {response.status_code}"
 
-def get_blueprint(deployment_id,client_token):
+def get_blueprint(deployment_id,token):
     url = f"{base_url}/training/blueprint"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     data = {
         "deployment_id" : deployment_id
     }
     response = requests.post(url,data=data,headers=headers)
     return json_check(response)
 
-def get_deploymentdetails(deployment_id,client_token):
+def get_deploymentdetails(deployment_id,token):
     url = f"{base_url}/training/deployment/{deployment_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return json_check(response)
     
-def get_project_details(project,client_token):
+def get_project_details(project,token):
     url = f"{base_url}/training/project/{project}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return json_check(response)
 
-def delete_deployment(deployment_id,client_token):
+def delete_deployment(deployment_id,token):
     url = f"{base_url}/training/deployment/{deployment_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.delete(url,headers=headers)
     return json_check(response)
 
-def delete_multiple_deployment(project_id,client_token):
+def delete_multiple_deployment(project_id,token):
     url = f"{base_url}/training/deployment-details/{project_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.delete(url,headers=headers)
     return json_check(response)
 
-def delete_project(project,client_token):
+def delete_project(project,token):
     url = f"{base_url}/training/project/{project}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.delete(url,headers=headers)
     return json_check(response)
 
-def update_deployment(deployment_id,model_id,client_token):
+def update_deployment(deployment_id,model_id,token):
     url = f"{base_url}/training/deployment/{deployment_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     data = {
         "model_id":model_id
     }
