@@ -1,9 +1,10 @@
 import requests
 from ..config import base_url, api_token
 
-def get_prediction_status(deployment_or_project_id, client_token, mode):
+def get_prediction_status(deployment_or_project_id, token, mode):
     url = ""
-    headers = {"Authorization": client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     url = f"{base_url}/prediction/check-prediction-status/{deployment_or_project_id}"
 
     try:
@@ -14,8 +15,9 @@ def get_prediction_status(deployment_or_project_id, client_token, mode):
         print(f"Request failed: {e}")
         return None
 
-def get_training_status(project_id,client_token):
+def get_training_status(project_id,token):
     url = f"{base_url}/training/check-status/{project_id}"
-    headers = {"Authorization":client_token}
+    access_token = 'Bearer '+ {token}
+    headers = {"Authorization": access_token}
     response = requests.get(url,headers=headers)
     return response.json()
\ No newline at end of file
